@@ -1,6 +1,10 @@
 # classes for messages in updates
 
-from .media import Photo, Video, Audio, Document
+from .media import PhotoSize, Video, Animation, Audio, Document
+# from .polls import Poll
+from .dice import Dice
+from .contact import Contact
+from .location import Location, Venue
 
 
 class Message:
@@ -13,15 +17,23 @@ class Message:
         self.text = data_['text'] if 'text' in data_ else None
         self.entities = MessageEntityList(
             data_['entities']) if 'entities' in data_ else None
-        self.photo = [Photo(photo) for photo in data_[
+        self.photo = [PhotoSize(photo) for photo in data_[
             'photo']] if 'photo' in data_ else None
         self.video = Video(data_['video']) if 'video' in data_ else None
+        self.animation = Animation(data_['animation']) if 'animation' in data_ else None
         self.audio = Audio(data_['audio']) if 'audio' in data_ else None
         self.document = Document(
             data_['document']) if 'document' in data_ else None
         self.new_chat_members = [User(user) for user in data_[
             'new_chat_members']] if 'new_chat_members' in data_ else None
+        self.dice = Dice(data_['dice']) if 'dice' in data_ else None
+        self.contact = Contact(data_['contact']) if 'contact' in data_ else None
+        self.location = Location(data_['location']) if 'location' in data_ else None
+        self.venue = Venue(data_['venue']) if 'venue' in data_ else None
 
+        # TODO fix circular import with Poll (which imports User)
+        # self.poll = Poll(data_['poll']) if 'poll' in data_ else None
+        
 
 class ChannelPost(Message):
     pass
